pub unsafe extern "C" fn Dart_ErrorHasException(
handle: Dart_Handle,
) -> boolExpand description
Is this an error handle for an unhandled exception?
pub unsafe extern "C" fn Dart_ErrorHasException(
handle: Dart_Handle,
) -> boolIs this an error handle for an unhandled exception?