Dart_FunctionName

Function Dart_FunctionName 

pub unsafe extern "C" fn Dart_FunctionName(
    function: Dart_Handle,
) -> Dart_Handle
Returns the name for the provided function or method.

\return A valid string handle if no error occurs during the operation.