pub unsafe extern "C" fn Dart_GetNativeResolver(
library: Dart_Handle,
resolver: *mut Dart_NativeEntryResolver,
) -> Dart_HandleExpand description
Returns the callback used to resolve native functions for a library.
\param library A library. \param resolver a pointer to a Dart_NativeEntryResolver
\return A valid handle if the library was found.