Dart_IsolateData

Function Dart_IsolateData 

pub unsafe extern "C" fn Dart_IsolateData(
    isolate: Dart_Isolate,
) -> *mut c_void
Returns the callback data associated with the given isolate. This data was set when the isolate got created or initialized.