pub unsafe extern "C" fn Dart_IsolateGroupData(
isolate: Dart_Isolate,
) -> *mut c_voidExpand description
Returns the callback data associated with the specified isolate group. This data was passed to the isolate when it was created. The embedder is responsible for ensuring the consistency of this data with respect to the lifecycle of an isolate group.