Dart_TypeToNullableType

Function Dart_TypeToNullableType 

pub unsafe extern "C" fn Dart_TypeToNullableType(
    type_: Dart_Handle,
) -> Dart_Handle
Creates a nullable version of the provided type.

\param type The type to be converted to a nullable type.

\return If no error occurs, a nullable type is returned. Otherwise an error handle is returned.