Dart_IsolateGroupId

Type Alias Dart_IsolateGroupId 

pub type Dart_IsolateGroupId = i64;
Gets an id that uniquely identifies current isolate group.

It is the responsibility of the caller to free the returned ID.