pub unsafe extern "C" fn Dart_FunctionName(
function: Dart_Handle,
) -> Dart_HandleExpand description
Returns the name for the provided function or method.
\return A valid string handle if no error occurs during the operation.
pub unsafe extern "C" fn Dart_FunctionName(
function: Dart_Handle,
) -> Dart_HandleReturns the name for the provided function or method.
\return A valid string handle if no error occurs during the operation.