pub unsafe extern "C" fn Dart_GetError(
handle: Dart_Handle,
) -> *const c_charExpand description
Gets the error message from an error handle.
Requires there to be a current isolate.
\return A C string containing an error message if the handle is error. An empty C string (“”) if the handle is valid. This C String is scope allocated and is only valid until the next call to Dart_ExitScope.