pub unsafe extern "C" fn Dart_IsolateData(
isolate: Dart_Isolate,
) -> *mut c_voidExpand description
Returns the callback data associated with the given isolate. This data was set when the isolate got created or initialized.
pub unsafe extern "C" fn Dart_IsolateData(
isolate: Dart_Isolate,
) -> *mut c_voidReturns the callback data associated with the given isolate. This data was set when the isolate got created or initialized.